import http from './interface'
import {
  platform
} from '../utils/index';
import store from '@/store/index.js'
const program = {
  H5: "wap",
  APP: "app",
  APPNVUE: "app",
  WEIXIN: "miniProgram"
};
const whiteCodes = [200, 201, 4444]

export const $http = (url, method, data, json) => {
  //设置请求前拦截器
  http.interceptor.request = (config) => {
    if (url !== '/homepage/study') {
      uni.showLoading({
        title: '加载中...'
      })
    }

    config.header = {
      "content-type": json ? 'application/json' : 'application/x-www-form-urlencoded',
      // "x-token": uni.getStorageSync('token'),
      "x-token": store.getters.token,
      "Program": program[platform()]
    }
  }
  //设置请求结束后拦截器
  http.interceptor.response = async (response) => {
    //判断返回状态 执行相应操作
    uni.hideLoading()
    const res = response.data;
    if (whiteCodes.indexOf(res.code) < 0) {
      uni.showToast({
        title: res.message || 'Error',
        icon: 'none',
        duration: 1500
      })

      if (res.code === 1001 || res.code === 7777 || res.code === 8888) {

        // return response.data = await doRequest(response, url)//动态刷新token,并重新完成request请求
        // store.dispatch('user/resetToken').then(() => {
        //   uni.navigateTo({
        //     url: '/pages/login/indexs'
        //   })
        // })

        // uni.navigateTo({
        //   url: '/pages/login/indexs'
        // })
      }
      return Promise.reject(new Error(res.message || 'Error'))
    } else {
      return res
    }
  }
  return http.request({
    method: method,
    url: url,
    dataType: 'json',
    data,
  })
}

async function login() {
  //返回环宇token所需的login code
  return new Promise(resolve => {
    uni.login({
      provider: 'weixin',
      success(loginRes) {
        resolve(loginRes.code)
      },
      fail() {}
    });
  })
}

async function doRequest(response, url) {
  var code = await login()
  var res = await get('/v1/oauth/refreshToken/code/' + code, {})
  if (res && res.data.data.token) {
    let config = response.config
    uni.setStorageSync("token", res.data.data.token);
    config.header['Authorization'] = res.data.data.token
    let json = config.header["Content-Type"] === 'application/json'
    const resold = await $http(url, config.method, {
      ...config.data
    }, json)
    return resold
  } else {
    uni.clearStorage()
    uni.showToast({
      title: "授权失效，请重新登录",
      duration: 1000,
    })
    uni.navigateTo({
      url: '/pages/login/auth'
    })
    return false
  }
}

function postJson(url, data) {
  return $http(url, 'POST', data)
}

function get(url, data) {
  return $http(url, 'GET', data)
}

function post(url, data) {
  return $http(url, 'POST', data, true)
}

function put(url, data) {
  return $http(url, 'PUT', data, true)
}

function del(url, data) {
  return $http(url, 'DELETE', data, true)
}

export default {
  postJson,
  get,
  post,
  put,
  del
}
